# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__all__ = ['ConvPadding', 'Interpolate']

import enum


class ConvPadding(enum.Enum):
    """An Enum holding the possible padding values for convolution modules."""
    SAME = 'SAME'
    VALID = 'VALID'


class Interpolate(enum.Enum):
    """An Enum holding the possible interpolation values for upsampling."""
    NEAREST = 'nearest'
    LINEAR = 'linear'
    BILINEAR = 'bilinear'
    TRILINEAR = 'trilinear'
    TRIANGLE = 'triangle'
    CUBIC = 'cubic'
    BICUBIC = 'bicubic'
    TRICUBIC = 'tricubic'
    LANCZOS3 = 'lanczos3'
    LANCZOS5 = 'lanczos5'
